diff -r -u3 --exclude-from=difexclude /usr/src/u-boot/cpu/mpc824x/drivers/epic/epic.h ppcboot-1.2.0/cpu/mpc824x/drivers/epic/epic.h
--- /usr/src/u-boot/cpu/mpc824x/drivers/epic/epic.h	Sat Nov  2 18:36:18 2002
+++ ppcboot-1.2.0/cpu/mpc824x/drivers/epic/epic.h	Tue Dec  3 15:56:29 2002
@@ -108,6 +108,9 @@
 #define EPIC_PROC_INT_ACK_REG (EPIC_EUMBBAR + 0x200a0)/* Int. acknowledge */
 #define EPIC_PROC_EOI_REG (EPIC_EUMBBAR + 0x200b0)/* End of interrupt */
 
+#define EPIC_VEC_PRI_MASK      0x80000000 /* Mask Interrupt bit in IVPR */
+#define EPIC_VEC_PRI_DFLT_PRI  8          /* Interrupt Priority in IVPR */
+
 /* Error code */
 
 #define OK       0
diff -r -u3 --exclude-from=difexclude /usr/src/u-boot/cpu/mpc824x/drivers/epic/epic1.c ppcboot-1.2.0/cpu/mpc824x/drivers/epic/epic1.c
--- /usr/src/u-boot/cpu/mpc824x/drivers/epic/epic1.c	Sat Aug 17 05:36:03 2002
+++ ppcboot-1.2.0/cpu/mpc824x/drivers/epic/epic1.c	Tue Dec  3 14:55:30 2002
@@ -70,6 +70,10 @@
     tmp = sysEUMBBARRead(EPIC_GLOBAL_REG);
     tmp |= 0xa0000000;                  /* Set the Global Conf. register */
     sysEUMBBARWrite(EPIC_GLOBAL_REG, tmp);
+	/*
+	 * Wait for EPIC to reset - CLH
+	 */
+    while( (sysEUMBBARRead(EPIC_GLOBAL_REG) & 0x80000000) == 1);
     sysEUMBBARWrite(EPIC_GLOBAL_REG, 0x20000000);
     tmp = sysEUMBBARRead(EPIC_INT_CONF_REG);    /* Read interrupt conf. reg */
 
@@ -81,7 +85,8 @@
         sysEUMBBARWrite(EPIC_INT_CONF_REG, tmp);
         }
 
-    while (epicIntAck() != 0xff);       /* Clear all pending interrupts */
+    while (epicIntAck() != 0xff)       /* Clear all pending interrupts */
+		epicEOI();
 }
 
 /****************************************************************************
@@ -92,18 +97,18 @@
  *
  *  RETURNS:  None
  */
-void epicIntEnable
-    (
-    int intVec        /* Interrupt Vector Number */
-    )
-    {
+void epicIntEnable(int intVec)
+{
     ULONG tmp;
     ULONG srAddr;
 
     srAddr = SrcVecTable[intVec].srcAddr;  /* Retrieve src Vec/Prio register */
     tmp = sysEUMBBARRead(srAddr);
-    tmp &= 0x7fffffff;             /* Clear the mask bit */
+    tmp &= ~EPIC_VEC_PRI_MASK;             /* Clear the mask bit */
+    tmp |= (EPIC_VEC_PRI_DFLT_PRI << 16);   /* Set priority to Default - CLH */
+    tmp |= intVec;				           /* Set Vector number */
     sysEUMBBARWrite(srAddr, tmp);
+
     return;
     }
 
--- /usr/src/u-boot/cpu/mpc824x/interrupts.c	Tue Aug 27 05:53:09 2002
+++ ppcboot-1.2.0/cpu/mpc824x/interrupts.c	Tue Dec  3 16:50:52 2002
@@ -92,6 +92,8 @@
 	 */
 
 	epicInit (EPIC_DIRECT_IRQ, 0);
+	/* EPIC won't generate INT unless Current Task Pri < 15 */
+	epicCurTaskPrioSet(0);
 
 	set_dec (decrementer_count);
 
